@@ -14,7 +14,7 @@ class Capabilities(types.BaseModel):
 class UnauthenticatedInspection(types.BaseModel):
     schema_version: str = "2024-05-24"
 
-    authentication_succeeded: typing.Optional[typing.Literal[False]]
+    authentication_succeeded: typing.Literal[False] | None
     function_count: int
     has_event_key: bool
     has_signing_key: bool
@@ -29,9 +29,9 @@ class AuthenticatedInspection(types.BaseModel):
     app_id: str
     authentication_succeeded: typing.Literal[True] = True
     capabilities: Capabilities = Capabilities()
-    env: typing.Optional[str]
+    env: str | None
     event_api_origin: str
-    event_key_hash: typing.Optional[str]
+    event_key_hash: str | None
     framework: str
     function_count: int
     has_event_key: bool
@@ -40,7 +40,7 @@ class AuthenticatedInspection(types.BaseModel):
     mode: ServerKind
     sdk_language: str = const.LANGUAGE
     sdk_version: str = const.VERSION
-    serve_origin: typing.Optional[str]
-    serve_path: typing.Optional[str]
-    signing_key_fallback_hash: typing.Optional[str]
-    signing_key_hash: typing.Optional[str]
+    serve_origin: str | None
+    serve_path: str | None
+    signing_key_fallback_hash: str | None
+    signing_key_hash: str | None
